pub enum Error {
BadName,
NotAStore,
BadData(Error),
UnsupportedPlatform(String),
IoError(Error),
Other(Box<dyn Error + Send + Sync>),
}Expand description
OpenPGP-Cert-D errors.
Errors defined by the Shared PGP Certificate Directory.
Variants
BadName
The name was neither a valid fingerprint, nor a known special name.
NotAStore
The base directory cannot possibly contain a store.
BadData(Error)
Error computing the fingerprint.
This means that the certificate data was malformed (e.g. because it was ASCII-Armored), or the certificate’s OpenPGP version was not supported by this crate.
UnsupportedPlatform(String)
Unsupported platform.
IoError(Error)
An IO error occurred.
Other(Box<dyn Error + Send + Sync>)
Any other error.
This is used to return arbitrary errors from
crate::CertD::insert, crate::CertD::try_insert,
crate::CertD::insert_special, and
crate::CertD::try_insert_special.